unit NListView;

{$IMPORTEDDATA OFF}

interface

uses NForm;

type
  TListView = class(TWindow)
    procedure AutoSizeColumn(Index: Integer; UseHeader: Boolean = False);
    function GetSelectedIndex: Integer;
    procedure InsertColumn(Index: Integer; const Text: WideString);
    procedure InsertRow(Index: Integer; const Texts: array of WideString);
    procedure SetFullRowSelect;
  end;

implementation

uses Windows, CommCtrlSub;

procedure TListView.AutoSizeColumn(Index: Integer; UseHeader: Boolean = False);
var
  v: LPARAM;
begin
  if UseHeader then
    v := LVSCW_AUTOSIZE_USEHEADER
  else
    v := LVSCW_AUTOSIZE;
  SendMessageW(Handle, LVM_SETCOLUMNWIDTH, Index, v);
end;

function TListView.GetSelectedIndex: Integer;
begin
  Result := SendMessageW(Handle, LVM_GETNEXTITEM, -1, LVIS_SELECTED);
end;

procedure TListView.InsertColumn(Index: Integer; const Text: WideString);
var
  lvc: LVCOLUMN;
begin
  lvc.mask := LVCF_TEXT or LVCF_SUBITEM;
  lvc.pszText := PWideChar(Text);
  lvc.iSubItem := Index;
  SendMessageW(Handle, LVM_INSERTCOLUMN, Index, WPARAM(@lvc));
end;

procedure TListView.InsertRow(Index: Integer; const Texts: array of WideString);
var
  i: Integer;
  lvi: LVITEM;
begin
  lvi.mask := LVIF_TEXT;
  lvi.iItem := Index;
  lvi.iSubItem := 0;
  lvi.pszText := PWideChar(Texts[0]);
  SendMessageW(Handle, LVM_INSERTITEM, 0, WPARAM(@lvi));
  for i := 1 to High(Texts) do begin
    lvi.iSubItem := i;
    lvi.pszText := PWideChar(Texts[i]);
    SendMessageW(Handle, LVM_SETITEM, 0, WPARAM(@lvi));
  end;
end;

procedure TListView.SetFullRowSelect;
begin
  SendMessageW(Handle, LVM_SETEXTENDEDLISTVIEWSTYLE,
      LVS_EX_FULLROWSELECT, LVS_EX_FULLROWSELECT);
end;

var
  icce: TInitCommonControlsEx;
begin
  icce.dwSize := SizeOf(icce);
  icce.dwICC := ICC_LISTVIEW_CLASSES;
  InitCommonControlsEx(icce);
end.
